@@ -68,7 +68,7 @@ public:
   virtual QString doPackages(int installFlags, QList<packageInfo *> p,
 			     bool &test) = 0;
 
-  QCheckBox **Boxs;
+  QCheckBox **Boxes;
   // options buttons
 
   QCheckBox *Keep;
