@@ -24,9 +24,11 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
+
 #include "Config.h"
+
 void ConfigFile::set(String const &key, String const &value, bool const &quote, bool const &removeIfEmpty, String const &prefix)
 {
 	String re="[ \t]*" + key + "[ \t]*=";
@@ -36,14 +38,14 @@ void ConfigFile::set(String const &key, String const &value, bool const &quote,
 			remove(s);
 	} else if(s.empty()) {
 		if(quote)
-			insert(end(), prefix + key + "=\"" + value + "\"");
+			insert(end(), prefix + key + "=\"" + value + "\"");	//krazy:exclude=duoblequote_char
 		else
 			insert(end(), prefix + key + "=" + value);
 	} else {
 		for(iterator it=begin(); it!=end(); it++)
 			if(!(*it).regex(re).empty()) {
 				if(quote)
-					(*it)=prefix + key + "=\"" + value +"\"";
+					(*it)=prefix + key + "=\"" + value +"\"";	//krazy:exclude=duoblequote_char
 				else
 					(*it)=prefix + key + "=" + value;
 				break;
