@@ -24,7 +24,7 @@
 */
 
 /*
-** Bug reports and questions can be sent to kde-devel@kde.org
+** Bug reports and questions can be sent to <kde-devel@kde.org>
 */
 /* Somewhat more sane string handling functions...                        *
  * Should be portable, therefore we aren't simply using QString.          */
@@ -43,14 +43,14 @@ typedef std::list<String> strlist;
 
 class String:public std::string {
 public:
-	String():std::string("") { };
-	String(char const * const &s):std::string(s) { };
-	String(std::string const &s):std::string(s) { };
+	String():std::string("") { }
+	String(char const * const &s):std::string(s) { }
+	String(std::string const &s):std::string(s) { }
 	String const operator +(char const &s);
 	String const operator +(char const * const s);
 	bool operator ==(char s);
 	bool operator !=(char s);
-	operator char * () const { return cstr(); };
+	operator char * () const { return cstr(); }
 	char * cstr() const;
 	bool cmp(char const * const s) const;
 	bool casecmp(char const * const s) const;
@@ -65,26 +65,26 @@ public:
 	String &regex(String const &expr, bool cs=true) const;
 	String &replace(String const &what, String const &with, bool all=true) const;
 	static String escapeForRegExp(String const &s);
-	char const chr(unsigned int index) const { if(index>=size()) return 0; else return data()[index]; };
-	int length() const { return size(); }; // For compatibility with QString
-	char const *latin1() const { return cstr(); }; // For compatibility with QString
+	char chr(unsigned int index) const { if(index>=size()) return 0; else return data()[index]; }
+	int length() const { return size(); } // For compatibility with QString
+	char const *latin1() const { return cstr(); } // For compatibility with QString
 };
 
 class StringList:public strlist {
 public:
-	StringList() { clear(); };
+	StringList() { clear(); }
 	StringList(String const &s);
 	StringList(char **strs, int num=-1);
 	bool readfile(String const &filename);
 	bool writefile(String const &filename) const;
-	void operator +=(String const &s) { insert(end(), s); };
-	void operator +=(char const * const &s) { insert(end(), s); };
+	void operator +=(String const &s) { insert(end(), s); }
+	void operator +=(char const * const &s) { insert(end(), s); }
 	void operator +=(StringList const &s);
 	void operator +=(StringList const * const s);
 	operator String() const;
 	bool contains(String const &s) const;
 	void remove(String const &s);
-	void add(String const &s) { insert(end(), s); };
+	void add(String const &s) { insert(end(), s); }
 	String const &grep(String const &s) const;
 	void sort(bool cs=true);
 };
